@@ -11,7 +11,7 @@ from logilab.common.modutils import LazyObject
 from logilab.mtconverter import guess_mimetype_and_encoding
 from yams import ValidationError
 
-from cubicweb import QueryError, typed_eid
+from cubicweb import Binary, QueryError, typed_eid
 from cubes.vcsfile import queries
 
 _VCSTYPES = {'subversion': LazyObject('cubes.vcsfile.reposvn', 'SVNRepository'),
@@ -105,7 +105,7 @@ def set_at_revision(session, reid, safetybelt=False):
     repository at any revision. This function set this relation for newly
     created revision.
     """
-    rqlexec = session.unsafe_execute
+    rqlexec = session.execute
     # link to version content generated by this revision
     #rql = 'SET VC at_revision REV WHERE REV eid %(rev)s, VC from_revision REV'
     #if safetybelt:
@@ -181,11 +181,11 @@ def import_version_content(session, repoeid, reveid, upath, date, **kwargs):
     mt, enc = guess_mimetype_and_encoding(
         fallbackencoding=repohdlr.encoding, fallbackmimetype=None,
         filename=upath)
-    args = {'vf': vfeid, 'rev': reveid,
+    args = {'vf': vfeid, 'rev': reveid, 'data': kwargs['data'],
             'df': mt and unicode(mt) or None,
             'de': enc and unicode(enc) or None}
     rql = ('INSERT VersionContent X: X from_revision REV, X content_for VF, '
-           'X data_format %(df)s, X data_encoding %(de)s')
+           'X data_format %(df)s, X data_encoding %(de)s, X data %(data)s')
     for inlinerel in ('vc_copy', 'vc_rename'):
         if inlinerel in kwargs:
             args[inlinerel] = kwargs[inlinerel]
@@ -202,3 +202,67 @@ def import_deleted_version_content(session, repoeid, reveid, upath, date):
     rql = ('INSERT DeletedVersionContent X: X from_revision REV, X content_for VF '
            ' WHERE REV eid %(rev)s, VF eid %(vf)s')
     return session.execute(rql, args)[0][0]
+
+
+from cubicweb import QueryError
+from cubicweb.server.sources import storages
+
+class VCSStorage(storages.Storage):
+    """store Bytes attribute value in a version content system"""
+
+    def callback(self, source, value):
+        """sql generator callback when some attribute with a custom storage is
+        accessed
+        """
+        repoeid, dir, name, revnum = source.binary_to_str(value).split('\x01')
+        repoeid = typed_eid(repoeid)
+        revnum = int(revnum)
+        try:
+            vcsrepohdlr = repository_handler(repoeid)
+        except Exception, ex:
+            source.critical("can't get repository handler for eid %s: %s",
+                            repoeid, ex)
+            return None
+        try:
+            return Binary(vcsrepohdlr.file_content(dir, name, revnum))
+        except Exception, ex:
+            source.critical("can't get content for %s/%s at revision %s in vcs "
+                            "repository %s: %s",
+                            dir, name, revnum, vcsrepohdlr, ex)
+            return None
+
+    def entity_added(self, entity, attr):
+        """an entity using this storage for attr has been added"""
+        try:
+            data = entity.pop(attr)
+        except KeyError:
+            pass
+        else:
+            session = entity._cw
+            # don't create vcs transaction if the revision is being imported
+            # from the vcs repository
+            try:
+                repoeid, dir, name, revnum = session.transaction_data['vcs_importing']
+            except KeyError:
+                vf = entity._vc_vf()
+                repoeid = vf.repository.eid
+                vcsrepohdlr, transaction = entity._vc_prepare(repoeid)
+                dir = vcsrepohdlr.encode(vf.directory)
+                name = vcsrepohdlr.encode(vf.name)
+                revnum = transaction.rev
+                vcsrepohdlr.add_versioned_file_content(session, transaction,
+                                                       vf, entity, data)
+            vckey = (str(repoeid), dir, name, str(revnum))
+            entity[attr] = Binary('\x01'.join(vckey))
+
+    def entity_updated(self, entity, attr):
+        """an entity using this storage for attr has been updatded"""
+        # XXX create a new revision to make this storage usable for arbitrary
+        # attributes
+        raise QueryError('read-only attribute')
+
+    def entity_deleted(self, entity, attr):
+        """an entity using this storage for attr has been deleted"""
+        # XXX delete from repository to make this storage usable for arbitrary
+        # attributes (unless vcs-importing, meaning a strip has been detected)
+        pass
