@@ -1,6 +1,5 @@
 """entity classes for vcsfile content types
 
-
 :organization: Logilab
 :copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
@@ -38,17 +37,22 @@ _MARKER = object()
 class Repository(AnyEntity):
     """customized class for Repository entities"""
     __regid__ ='Repository'
-    fetch_attrs, fetch_order = fetch_config(['path', 'subpath', 'type'])
+    fetch_attrs, fetch_order = fetch_config(['title', 'path', 'subpath', 'type'])
     rest_attr = 'eid' # see #XXX, using path cause pb w/ apache redirection
 
     def dc_title(self):
-        title = '%s:%s' % (self.type, self.path)
-        if self.subpath:
-            title += ' (%s)' % self.subpath
+        if self.title:
+            return self.title
+        try:
+            title = '%s:%s' % (self.type, self.path)
+            if self.subpath:
+                title += ' (%s)' % self.subpath
+        except Unauthorized:
+            title = self._cw._('unauthorized')
         return title
 
     def clear_all_caches(self):
-        super(VersionedFile, self).clear_all_caches()
+        super(Repository, self).clear_all_caches()
         clear_cache(self, 'branch_head')
 
     # navigation in versioned content #########################################
@@ -57,7 +61,7 @@ class Repository(AnyEntity):
         """return the number of the latest known revision"""
         latestrev = self._cw.execute(
             'Any MAX(REVR) WHERE R eid %(r)s, REV from_repository R, '
-            'REV revision REVR', {'r' : self.eid}, 'r')[0][0]
+            'REV revision REVR', {'r' : self.eid})[0][0]
         if latestrev is None:
             return -1
         return latestrev
@@ -66,7 +70,7 @@ class Repository(AnyEntity):
         """return existing branches"""
         return [b for b, in self._cw.execute(
             'DISTINCT Any B WHERE R eid %(r)s, REV from_repository R, '
-            'REV branch B', {'r' : self.eid}, 'r')]
+            'REV branch B', {'r' : self.eid})]
 
     @cached
     def branch_head(self, branch=_MARKER):
@@ -76,7 +80,7 @@ class Repository(AnyEntity):
         rset = self._cw.execute(
             'Any MAX(REV) WHERE V at_revision REV, REV branch %(branch)s, '
             'REV from_repository R, R eid %(r)s',
-            {'r': self.eid, 'branch': branch}, 'r')
+            {'r': self.eid, 'branch': branch})
         if rset[0][0] is None:
             return None
         return rset.get_entity(0, 0)
@@ -94,7 +98,7 @@ class Repository(AnyEntity):
             'Any MAX(VC), MAX(REV) GROUPBY VF '
             'WHERE VC from_revision R, R revision REV, R from_repository X, '
             'X eid %(x)s, VC content_for VF, VF directory ~= %(dir)s',
-            {'x': self.eid, 'dir': directory}, 'x')
+            {'x': self.eid, 'dir': directory})
         return not any(e for e in rset.entities() if e.__regid__ == 'VersionContent')
 
     # vcs write support ########################################################
@@ -154,7 +158,8 @@ class Revision(AnyEntity):
     """customized class for Revision entities"""
     __regid__ ='Revision'
     fetch_attrs, fetch_order = fetch_config(['revision', 'changeset', 'author',
-                                             'description', 'creation_date'])
+                                             'description', 'creation_date'],
+                                            order='DESC')
     __implements__ = AnyEntity.__implements__ + (IPrevNext,)
 
     def dc_title(self):
@@ -276,7 +281,7 @@ class VersionedFile(AnyEntity):
         rset = self._cw.execute(
             'Any C,VF,R WHERE C content_for VF, C from_revision R, '
             'R revision %(rnum)s, VF eid %(x)s',
-            {'rnum' : int(revnum), 'x' : self.eid}, 'x')
+            {'rnum' : int(revnum), 'x' : self.eid})
         if rset:
             return rset.get_entity(0, 0)
         return None
@@ -291,7 +296,7 @@ class VersionedFile(AnyEntity):
         rset = self._cw.execute(
             'Any MAX(V) WHERE X eid %(x)s, V content_for X, V at_revision REV, '
             'REV branch %(branch)s',
-            {'x': self.eid, 'branch': branch}, 'x')
+            {'x': self.eid, 'branch': branch})
         # content_for relation is not mandatory on VersionedFile entities
         if rset[0][0] is None:
             return None
@@ -322,7 +327,7 @@ class VersionedFile(AnyEntity):
         self._cw.execute(
             'INSERT DeletedVersionContent D: D content_for X, '
             'D from_revision R WHERE X eid %(x)s, R eid %(r)s',
-            {'x' : self.eid, 'r' : rev.eid}, ('x', 'r'))
+            {'x' : self.eid, 'r' : rev.eid})
 
     def vcs_upload_revision(self, stream, rev=None, **kwargs):
         """upload a new revision for this file to the vcs
@@ -437,7 +442,7 @@ class DeletedVersionContent(AnyEntity):
                 raise missing_relation_error(self, 'content_for')
             vf = self._cw.execute(
                 'Any X, R, FD, FN WHERE X directory FD, X name FN, X eid %(x)s, '
-                'X from_repository R', {'x': vfeid}, 'x').get_entity(0, 0)
+                'X from_repository R', {'x': vfeid}).get_entity(0, 0)
             self._vcsrepo_info = vf
         return self._vcsrepo_info
 
@@ -451,7 +456,7 @@ class DeletedVersionContent(AnyEntity):
             # retrieve associated VersionedFile instance
             vf = session.execute('Any X,D,N,R WHERE X name N, X directory D,'
                                  'X from_repository R, X eid %(x)s',
-                                 {'x': vfeid}, 'x').get_entity(0, 0)
+                                 {'x': vfeid}).get_entity(0, 0)
             vcsrepoeid = vf.repository.eid
         try:
             transaction = session.transaction_data['vctransactions'][vcsrepoeid]
