@@ -114,8 +114,10 @@ class HGRepository(repo.VCSRepository):
             upath = unicode(path, self.encoding, 'replace')
             if not (path_filter is None or upath.startswith(path_filter)):
                 continue
-            vcdata = {}
+            directory, fname = split(path)
+            session.transaction_data['vcs_importing'] = self.eid, directory, fname, i
             filectx = ctx[path]
+            vcdata = {'data': filectx.data()}
             renameinfo = filectx.renamed()
             if renameinfo:
                 oldfile, fileid = renameinfo
@@ -146,7 +148,6 @@ class HGRepository(repo.VCSRepository):
                 continue
             bridge.import_deleted_version_content(session, self.eid, reveid,
                                                   upath, date)
-        # The line below is duplicated at the middle of the function
         bridge.set_at_revision(session, reveid)
 
     def hgrepo(self):
@@ -259,7 +260,7 @@ class HGTransaction(object):
         source = self.session.repo.system_source
          # remove previous cached value to only save the changeset
         self.revision.clear()
-        self.revision['eid'] = self.revision.eid
+        self.revision.edited_attributes = set()
         self.revision['changeset'] = unicode(short_hex(node))
         source.update_entity(self.session, self.revision)
         # XXX restore entity's dict?
